# HP23005UNO

`HP23005UNO` es una librería de Python que permite resolver sistemas de ecuaciones lineales y no lineales mediante distintos metodos numericos.

## Metodos disponibles

### Ecuaciones lineales:
- Eliminacion de Gauss
- Gauss-Jordan
- Regla de Cramer
- Descomposicion LU
- Metodo de Jacobi
- Metodo de Gauss-Seidel

### Ecuaciones no lineales:
- Metodo de Bisección

## Instalación
```bash
.\venv\Scripts\Activate
pip numpy
pip install --upgrade setuptools pip wheel
pip install --upgrade HP23005UNO
